summaryrefslogtreecommitdiffstats
path: root/src/dolphinview.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-27 00:40:29 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-27 00:40:29 +0000
commit7a741e43ff09e70396a918956219b8316c48e522 (patch)
tree3d0f60eccd59786cea7236db2d5c4c1f25874515 /src/dolphinview.h
parenta48487ef0c329434b58b6f920111bb0999f1109e (diff)
downloaddolphin-7a741e43ff09e70396a918956219b8316c48e522.tar.gz
dolphin-7a741e43ff09e70396a918956219b8316c48e522.zip
TQt4 port Dolphin
This enables compilation under Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/dolphin@1229359 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/dolphinview.h')
-rw-r--r--src/dolphinview.h67
1 files changed, 34 insertions, 33 deletions
diff --git a/src/dolphinview.h b/src/dolphinview.h
index d0ad891..7a67bc0 100644
--- a/src/dolphinview.h
+++ b/src/dolphinview.h
@@ -22,21 +22,21 @@
#ifndef _DOLPHINVIEW_H_
#define _DOLPHINVIEW_H_
-#include <qwidget.h>
+#include <tqwidget.h>
#include <kparts/part.h>
#include <kfileitem.h>
#include <kfileiconview.h>
#include <kio/job.h>
#include <urlnavigator.h>
-class QPainter;
+class TQPainter;
class KURL;
-class QLineEdit;
+class TQLineEdit;
class URLNavigator;
-class QTimer;
-class QIconViewItem;
-class QListViewItem;
-class QVBoxLayout;
+class TQTimer;
+class TQIconViewItem;
+class TQListViewItem;
+class TQVBoxLayout;
class KFileView;
class Dolphin;
class DolphinDirLister;
@@ -44,7 +44,7 @@ class DolphinStatusBar;
class DolphinIconsView;
class DolphinDetailsView;
class ViewProperties;
-class QScrollView;
+class TQScrollView;
class KProgress;
class ItemEffectsManager;
class FilterBar;
@@ -62,9 +62,10 @@ class FilterBar;
*
* @author Peter Penz <peter.penz@gmx.at>
*/
-class DolphinView : public QWidget
+class DolphinView : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
@@ -102,7 +103,7 @@ public:
SortByDate = 2
};
- DolphinView(QWidget* parent,
+ DolphinView(TQWidget* tqparent,
const KURL& url,
Mode mode = IconsView,
bool showHiddenFiles = false);
@@ -194,7 +195,7 @@ public:
* @param index Output parameter which indicates the current
* index of the location.
*/
- const QValueList<URLNavigator::HistoryElem> urlHistory(int& index) const;
+ const TQValueList<URLNavigator::HistoryElem> urlHistory(int& index) const;
/**
* Returns true, if at least one item is selected.
@@ -228,14 +229,14 @@ public:
* on the position \a pos. If 0 is passed for the file info, a context
* menu for the viewport is opened.
*/
- void openContextMenu(KFileItem* fileInfo, const QPoint& pos);
+ void openContextMenu(KFileItem* fileInfo, const TQPoint& pos);
/**
* Renames the filename of the source URL by the new file name.
* If the new file name already exists, a dialog is opened which
* asks the user to enter a new name.
*/
- void rename(const KURL& source, const QString& newName);
+ void rename(const KURL& source, const TQString& newName);
/** Returns the status bar of the view. */
DolphinStatusBar* statusBar() const;
@@ -284,11 +285,11 @@ public:
/** Returns the sort order of the items inside a directory (see DolphinView::Sorting). */
Sorting sorting() const;
- /** Sets the sort order (Qt::Ascending or Qt::Descending) for the items. */
- void setSortOrder(Qt::SortOrder order);
+ /** Sets the sort order (TQt::Ascending or TQt::Descending) for the items. */
+ void setSortOrder(TQt::SortOrder order);
- /** Returns the current used sort order (Qt::Ascending or Qt::Descending). */
- Qt::SortOrder sortOrder() const;
+ /** Returns the current used sort order (TQt::Ascending or TQt::Descending). */
+ TQt::SortOrder sortOrder() const;
/** Refreshs the view settings by reading out the stored settings. */
void refreshSettings();
@@ -321,7 +322,7 @@ public:
public slots:
void reload();
- void slotURLListDropped(QDropEvent* event,
+ void slotURLListDropped(TQDropEvent* event,
const KURL::List& urls,
const KURL& url);
@@ -347,7 +348,7 @@ signals:
void signalSortingChanged(DolphinView::Sorting sorting);
/** Is emitted if the sort order (ascending or descending) has been changed. */
- void signalSortOrderChanged(Qt::SortOrder order);
+ void signalSortOrderChanged(TQt::SortOrder order);
/**
* Is emitted if information of an item is requested to be shown e. g. in the sidebar.
@@ -366,16 +367,16 @@ signals:
void signalSelectionChanged();
protected:
- /** @see QWidget::mouseReleaseEvent */
- virtual void mouseReleaseEvent(QMouseEvent* event);
+ /** @see TQWidget::mouseReleaseEvent */
+ virtual void mouseReleaseEvent(TQMouseEvent* event);
private slots:
void slotURLChanged(const KURL& kurl);
- void triggerIconsViewItem(QIconViewItem *item);
- void triggerDetailsViewItem(QListViewItem* item,
- const QPoint& pos,
+ void triggerIconsViewItem(TQIconViewItem *item);
+ void triggerDetailsViewItem(TQListViewItem* item,
+ const TQPoint& pos,
int column);
- void triggerDetailsViewItem(QListViewItem* item);
+ void triggerDetailsViewItem(TQListViewItem* item);
void updateURL();
void slotPercent(int percent);
@@ -383,8 +384,8 @@ private slots:
void slotDeleteItem(KFileItem* item);
void slotCompleted();
void slotDelayedUpdate();
- void slotInfoMessage(const QString& msg);
- void slotErrorMessage(const QString& msg);
+ void slotInfoMessage(const TQString& msg);
+ void slotErrorMessage(const TQString& msg);
void slotRefreshItems(const KFileItemList& list);
void slotAddItems(const KFileItemList& list);
@@ -402,12 +403,12 @@ private slots:
* Filters the currently shown items by \a nameFilter. All items
* which contain the given filter string will be shown.
*/
- void slotChangeNameFilter(const QString& nameFilter);
+ void slotChangeNameFilter(const TQString& nameFilter);
private:
void createView();
KFileView* fileView() const;
- QScrollView* scrollView() const;
+ TQScrollView* scrollView() const;
ItemEffectsManager* itemEffectsManager() const;
void startDirLister(const KURL& url, bool reload = false);
@@ -415,25 +416,25 @@ private:
* Returns the default text of the status bar, if no item is
* selected.
*/
- QString defaultStatusBarText() const;
+ TQString defaultStatusBarText() const;
/**
* Returns the text for the status bar, if at least one item
* is selected.
*/
- QString selectionStatusBarText() const;
+ TQString selectionStatusBarText() const;
/**
* Returns the string representation for the index \a index
* for renaming \itemCount items.
*/
- QString renameIndexPresentation(int index, int itemCount) const;
+ TQString renameIndexPresentation(int index, int itemCount) const;
bool m_refreshing;
bool m_showProgress;
Mode m_mode;
- QVBoxLayout* m_topLayout;
+ TQVBoxLayout* m_topLayout;
URLNavigator* m_urlNavigator;
DolphinIconsView* m_iconsView;